@@ -1,18 +1,54 @@
-#[doc = "Reader of register INTF"]
-pub type R = crate::R<u32, super::INTF>;
-#[doc = "Writer for register INTF"]
-pub type W = crate::W<u32, super::INTF>;
-#[doc = "Register INTF `reset()`'s with value 0"]
-impl crate::ResetValue for super::INTF {
-    type Type = u32;
+#[doc = "Register `INTF` reader"]
+pub struct R(crate::R<INTF_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<INTF_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
-#[doc = "Reader of field `EP_STALL_NAK`"]
-pub type EP_STALL_NAK_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP_STALL_NAK`"]
+impl From<crate::R<INTF_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<INTF_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `INTF` writer"]
+pub struct W(crate::W<INTF_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<INTF_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<INTF_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<INTF_SPEC>) -> Self {
+        W(writer)
+    }
+}
+#[doc = "Field `EP_STALL_NAK` reader - Raised when any bit in EP_STATUS_STALL_NAK is set. Clear by clearing all bits in EP_STATUS_STALL_NAK."]
+pub struct EP_STALL_NAK_R(crate::FieldReader<bool, bool>);
+impl EP_STALL_NAK_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP_STALL_NAK_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP_STALL_NAK_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP_STALL_NAK` writer - Raised when any bit in EP_STATUS_STALL_NAK is set. Clear by clearing all bits in EP_STATUS_STALL_NAK."]
 pub struct EP_STALL_NAK_W<'a> {
     w: &'a mut W,
 }
@@ -30,13 +66,25 @@ impl<'a> EP_STALL_NAK_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
-#[doc = "Reader of field `ABORT_DONE`"]
-pub type ABORT_DONE_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `ABORT_DONE`"]
+#[doc = "Field `ABORT_DONE` reader - Raised when any bit in ABORT_DONE is set. Clear by clearing all bits in ABORT_DONE."]
+pub struct ABORT_DONE_R(crate::FieldReader<bool, bool>);
+impl ABORT_DONE_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        ABORT_DONE_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for ABORT_DONE_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ABORT_DONE` writer - Raised when any bit in ABORT_DONE is set. Clear by clearing all bits in ABORT_DONE."]
 pub struct ABORT_DONE_W<'a> {
     w: &'a mut W,
 }
@@ -54,13 +102,25 @@ impl<'a> ABORT_DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
-#[doc = "Reader of field `DEV_SOF`"]
-pub type DEV_SOF_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `DEV_SOF`"]
+#[doc = "Field `DEV_SOF` reader - Set every time the device receives a SOF (Start of Frame) packet. Cleared by reading SOF_RD"]
+pub struct DEV_SOF_R(crate::FieldReader<bool, bool>);
+impl DEV_SOF_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DEV_SOF_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for DEV_SOF_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `DEV_SOF` writer - Set every time the device receives a SOF (Start of Frame) packet. Cleared by reading SOF_RD"]
 pub struct DEV_SOF_W<'a> {
     w: &'a mut W,
 }
@@ -78,13 +138,25 @@ impl<'a> DEV_SOF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
-#[doc = "Reader of field `SETUP_REQ`"]
-pub type SETUP_REQ_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `SETUP_REQ`"]
+#[doc = "Field `SETUP_REQ` reader - Device. Source: SIE_STATUS.SETUP_REC"]
+pub struct SETUP_REQ_R(crate::FieldReader<bool, bool>);
+impl SETUP_REQ_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        SETUP_REQ_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for SETUP_REQ_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `SETUP_REQ` writer - Device. Source: SIE_STATUS.SETUP_REC"]
 pub struct SETUP_REQ_W<'a> {
     w: &'a mut W,
 }
@@ -102,13 +174,25 @@ impl<'a> SETUP_REQ_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
-#[doc = "Reader of field `DEV_RESUME_FROM_HOST`"]
-pub type DEV_RESUME_FROM_HOST_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `DEV_RESUME_FROM_HOST`"]
+#[doc = "Field `DEV_RESUME_FROM_HOST` reader - Set when the device receives a resume from the host. Cleared by writing to SIE_STATUS.RESUME"]
+pub struct DEV_RESUME_FROM_HOST_R(crate::FieldReader<bool, bool>);
+impl DEV_RESUME_FROM_HOST_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DEV_RESUME_FROM_HOST_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for DEV_RESUME_FROM_HOST_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `DEV_RESUME_FROM_HOST` writer - Set when the device receives a resume from the host. Cleared by writing to SIE_STATUS.RESUME"]
 pub struct DEV_RESUME_FROM_HOST_W<'a> {
     w: &'a mut W,
 }
@@ -126,13 +210,25 @@ impl<'a> DEV_RESUME_FROM_HOST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | (((value as u32) & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
         self.w
     }
 }
-#[doc = "Reader of field `DEV_SUSPEND`"]
-pub type DEV_SUSPEND_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `DEV_SUSPEND`"]
+#[doc = "Field `DEV_SUSPEND` reader - Set when the device suspend state changes. Cleared by writing to SIE_STATUS.SUSPENDED"]
+pub struct DEV_SUSPEND_R(crate::FieldReader<bool, bool>);
+impl DEV_SUSPEND_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DEV_SUSPEND_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for DEV_SUSPEND_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `DEV_SUSPEND` writer - Set when the device suspend state changes. Cleared by writing to SIE_STATUS.SUSPENDED"]
 pub struct DEV_SUSPEND_W<'a> {
     w: &'a mut W,
 }
@@ -150,13 +246,25 @@ impl<'a> DEV_SUSPEND_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | (((value as u32) & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
         self.w
     }
 }
-#[doc = "Reader of field `DEV_CONN_DIS`"]
-pub type DEV_CONN_DIS_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `DEV_CONN_DIS`"]
+#[doc = "Field `DEV_CONN_DIS` reader - Set when the device connection state changes. Cleared by writing to SIE_STATUS.CONNECTED"]
+pub struct DEV_CONN_DIS_R(crate::FieldReader<bool, bool>);
+impl DEV_CONN_DIS_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DEV_CONN_DIS_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for DEV_CONN_DIS_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `DEV_CONN_DIS` writer - Set when the device connection state changes. Cleared by writing to SIE_STATUS.CONNECTED"]
 pub struct DEV_CONN_DIS_W<'a> {
     w: &'a mut W,
 }
@@ -174,13 +282,25 @@ impl<'a> DEV_CONN_DIS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | (((value as u32) & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
         self.w
     }
 }
-#[doc = "Reader of field `BUS_RESET`"]
-pub type BUS_RESET_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `BUS_RESET`"]
+#[doc = "Field `BUS_RESET` reader - Source: SIE_STATUS.BUS_RESET"]
+pub struct BUS_RESET_R(crate::FieldReader<bool, bool>);
+impl BUS_RESET_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        BUS_RESET_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for BUS_RESET_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `BUS_RESET` writer - Source: SIE_STATUS.BUS_RESET"]
 pub struct BUS_RESET_W<'a> {
     w: &'a mut W,
 }
@@ -198,13 +318,25 @@ impl<'a> BUS_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
-#[doc = "Reader of field `VBUS_DETECT`"]
-pub type VBUS_DETECT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `VBUS_DETECT`"]
+#[doc = "Field `VBUS_DETECT` reader - Source: SIE_STATUS.VBUS_DETECT"]
+pub struct VBUS_DETECT_R(crate::FieldReader<bool, bool>);
+impl VBUS_DETECT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        VBUS_DETECT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for VBUS_DETECT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `VBUS_DETECT` writer - Source: SIE_STATUS.VBUS_DETECT"]
 pub struct VBUS_DETECT_W<'a> {
     w: &'a mut W,
 }
@@ -222,13 +354,25 @@ impl<'a> VBUS_DETECT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
-#[doc = "Reader of field `STALL`"]
-pub type STALL_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `STALL`"]
+#[doc = "Field `STALL` reader - Source: SIE_STATUS.STALL_REC"]
+pub struct STALL_R(crate::FieldReader<bool, bool>);
+impl STALL_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        STALL_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for STALL_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `STALL` writer - Source: SIE_STATUS.STALL_REC"]
 pub struct STALL_W<'a> {
     w: &'a mut W,
 }
@@ -246,13 +390,25 @@ impl<'a> STALL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
-#[doc = "Reader of field `ERROR_CRC`"]
-pub type ERROR_CRC_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `ERROR_CRC`"]
+#[doc = "Field `ERROR_CRC` reader - Source: SIE_STATUS.CRC_ERROR"]
+pub struct ERROR_CRC_R(crate::FieldReader<bool, bool>);
+impl ERROR_CRC_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        ERROR_CRC_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for ERROR_CRC_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ERROR_CRC` writer - Source: SIE_STATUS.CRC_ERROR"]
 pub struct ERROR_CRC_W<'a> {
     w: &'a mut W,
 }
@@ -270,13 +426,25 @@ impl<'a> ERROR_CRC_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
-#[doc = "Reader of field `ERROR_BIT_STUFF`"]
-pub type ERROR_BIT_STUFF_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `ERROR_BIT_STUFF`"]
+#[doc = "Field `ERROR_BIT_STUFF` reader - Source: SIE_STATUS.BIT_STUFF_ERROR"]
+pub struct ERROR_BIT_STUFF_R(crate::FieldReader<bool, bool>);
+impl ERROR_BIT_STUFF_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        ERROR_BIT_STUFF_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for ERROR_BIT_STUFF_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ERROR_BIT_STUFF` writer - Source: SIE_STATUS.BIT_STUFF_ERROR"]
 pub struct ERROR_BIT_STUFF_W<'a> {
     w: &'a mut W,
 }
@@ -294,13 +462,25 @@ impl<'a> ERROR_BIT_STUFF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
-#[doc = "Reader of field `ERROR_RX_OVERFLOW`"]
-pub type ERROR_RX_OVERFLOW_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `ERROR_RX_OVERFLOW`"]
+#[doc = "Field `ERROR_RX_OVERFLOW` reader - Source: SIE_STATUS.RX_OVERFLOW"]
+pub struct ERROR_RX_OVERFLOW_R(crate::FieldReader<bool, bool>);
+impl ERROR_RX_OVERFLOW_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        ERROR_RX_OVERFLOW_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for ERROR_RX_OVERFLOW_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ERROR_RX_OVERFLOW` writer - Source: SIE_STATUS.RX_OVERFLOW"]
 pub struct ERROR_RX_OVERFLOW_W<'a> {
     w: &'a mut W,
 }
@@ -318,13 +498,25 @@ impl<'a> ERROR_RX_OVERFLOW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
-#[doc = "Reader of field `ERROR_RX_TIMEOUT`"]
-pub type ERROR_RX_TIMEOUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `ERROR_RX_TIMEOUT`"]
+#[doc = "Field `ERROR_RX_TIMEOUT` reader - Source: SIE_STATUS.RX_TIMEOUT"]
+pub struct ERROR_RX_TIMEOUT_R(crate::FieldReader<bool, bool>);
+impl ERROR_RX_TIMEOUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        ERROR_RX_TIMEOUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for ERROR_RX_TIMEOUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ERROR_RX_TIMEOUT` writer - Source: SIE_STATUS.RX_TIMEOUT"]
 pub struct ERROR_RX_TIMEOUT_W<'a> {
     w: &'a mut W,
 }
@@ -342,13 +534,25 @@ impl<'a> ERROR_RX_TIMEOUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
-#[doc = "Reader of field `ERROR_DATA_SEQ`"]
-pub type ERROR_DATA_SEQ_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `ERROR_DATA_SEQ`"]
+#[doc = "Field `ERROR_DATA_SEQ` reader - Source: SIE_STATUS.DATA_SEQ_ERROR"]
+pub struct ERROR_DATA_SEQ_R(crate::FieldReader<bool, bool>);
+impl ERROR_DATA_SEQ_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        ERROR_DATA_SEQ_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for ERROR_DATA_SEQ_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ERROR_DATA_SEQ` writer - Source: SIE_STATUS.DATA_SEQ_ERROR"]
 pub struct ERROR_DATA_SEQ_W<'a> {
     w: &'a mut W,
 }
@@ -366,13 +570,25 @@ impl<'a> ERROR_DATA_SEQ_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
-#[doc = "Reader of field `BUFF_STATUS`"]
-pub type BUFF_STATUS_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `BUFF_STATUS`"]
+#[doc = "Field `BUFF_STATUS` reader - Raised when any bit in BUFF_STATUS is set. Clear by clearing all bits in BUFF_STATUS."]
+pub struct BUFF_STATUS_R(crate::FieldReader<bool, bool>);
+impl BUFF_STATUS_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        BUFF_STATUS_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for BUFF_STATUS_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `BUFF_STATUS` writer - Raised when any bit in BUFF_STATUS is set. Clear by clearing all bits in BUFF_STATUS."]
 pub struct BUFF_STATUS_W<'a> {
     w: &'a mut W,
 }
@@ -390,13 +606,25 @@ impl<'a> BUFF_STATUS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
-#[doc = "Reader of field `TRANS_COMPLETE`"]
-pub type TRANS_COMPLETE_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `TRANS_COMPLETE`"]
+#[doc = "Field `TRANS_COMPLETE` reader - Raised every time SIE_STATUS.TRANS_COMPLETE is set. Clear by writing to this bit."]
+pub struct TRANS_COMPLETE_R(crate::FieldReader<bool, bool>);
+impl TRANS_COMPLETE_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        TRANS_COMPLETE_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TRANS_COMPLETE_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TRANS_COMPLETE` writer - Raised every time SIE_STATUS.TRANS_COMPLETE is set. Clear by writing to this bit."]
 pub struct TRANS_COMPLETE_W<'a> {
     w: &'a mut W,
 }
@@ -414,13 +642,25 @@ impl<'a> TRANS_COMPLETE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
-#[doc = "Reader of field `HOST_SOF`"]
-pub type HOST_SOF_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `HOST_SOF`"]
+#[doc = "Field `HOST_SOF` reader - Host: raised every time the host sends a SOF (Start of Frame). Cleared by reading SOF_RD"]
+pub struct HOST_SOF_R(crate::FieldReader<bool, bool>);
+impl HOST_SOF_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        HOST_SOF_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for HOST_SOF_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `HOST_SOF` writer - Host: raised every time the host sends a SOF (Start of Frame). Cleared by reading SOF_RD"]
 pub struct HOST_SOF_W<'a> {
     w: &'a mut W,
 }
@@ -438,13 +678,25 @@ impl<'a> HOST_SOF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
-#[doc = "Reader of field `HOST_RESUME`"]
-pub type HOST_RESUME_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `HOST_RESUME`"]
+#[doc = "Field `HOST_RESUME` reader - Host: raised when a device wakes up the host. Cleared by writing to SIE_STATUS.RESUME"]
+pub struct HOST_RESUME_R(crate::FieldReader<bool, bool>);
+impl HOST_RESUME_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        HOST_RESUME_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for HOST_RESUME_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `HOST_RESUME` writer - Host: raised when a device wakes up the host. Cleared by writing to SIE_STATUS.RESUME"]
 pub struct HOST_RESUME_W<'a> {
     w: &'a mut W,
 }
@@ -462,13 +714,25 @@ impl<'a> HOST_RESUME_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
-#[doc = "Reader of field `HOST_CONN_DIS`"]
-pub type HOST_CONN_DIS_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `HOST_CONN_DIS`"]
+#[doc = "Field `HOST_CONN_DIS` reader - Host: raised when a device is connected or disconnected (i.e. when SIE_STATUS.SPEED changes). Cleared by writing to SIE_STATUS.SPEED"]
+pub struct HOST_CONN_DIS_R(crate::FieldReader<bool, bool>);
+impl HOST_CONN_DIS_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        HOST_CONN_DIS_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for HOST_CONN_DIS_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `HOST_CONN_DIS` writer - Host: raised when a device is connected or disconnected (i.e. when SIE_STATUS.SPEED changes). Cleared by writing to SIE_STATUS.SPEED"]
 pub struct HOST_CONN_DIS_W<'a> {
     w: &'a mut W,
 }
@@ -486,7 +750,7 @@ impl<'a> HOST_CONN_DIS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -693,4 +957,34 @@ impl W {
     pub fn host_conn_dis(&mut self) -> HOST_CONN_DIS_W {
         HOST_CONN_DIS_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Interrupt Force  
+
+This register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).  
+
+For information about available fields see [intf](index.html) module"]
+pub struct INTF_SPEC;
+impl crate::RegisterSpec for INTF_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [intf::R](R) reader structure"]
+impl crate::Readable for INTF_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [intf::W](W) writer structure"]
+impl crate::Writable for INTF_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets INTF to value 0"]
+impl crate::Resettable for INTF_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
